==> open-xchange-core_6.22.1.orig.tar.bz2: open-xchange-core-6.22.1/com.openexchange.secret.recovery/src/com/openexchange/secret/recovery/impl/DefaultSecretInconsistencyDetector.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.secret.recovery.impl;

import java.util.ArrayList;
import java.util.List;
import org.apache.commons.logging.Log;
import com.openexchange.log.LogFactory;
import com.openexchange.exception.OXException;
import com.openexchange.secret.SecretService;
import com.openexchange.secret.recovery.SecretConsistencyCheck;
import com.openexchange.secret.recovery.SecretInconsistencyDetector;
import com.openexchange.tools.session.ServerSession;

/**
 * {@link DefaultSecretInconsistencyDetector}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class DefaultSecretInconsistencyDetector implements SecretInconsistencyDetector {

    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(DefaultSecretInconsistencyDetector.class));

    private static final boolean DEBUG = LOG.isDebugEnabled();

    private final List<SecretConsistencyCheck> checks;

    private SecretService secretService;

    /**
     * Initializes a new {@link DefaultSecretInconsistencyDetector}.
     */
    public DefaultSecretInconsistencyDetector() {
        super();
        checks = new ArrayList<SecretConsistencyCheck>();
    }

    @Override
    public String isSecretWorking(final ServerSession session) throws OXException {
        for (final SecretConsistencyCheck secretConsistencyCheck : getChecks()) {
            final String reason = secretConsistencyCheck.checkSecretCanDecryptStrings(session, getSecretService().getSecret(session));
            if (reason != null) {
                if (DEBUG) {
                    LOG.debug(SecretConsistencyCheck.class.getSimpleName() + " \"" + secretConsistencyCheck.getClass().getName() + "\" indicates need for re-decryption: " + reason);
                }
                return reason;
            }
        }
        return null;
    }

    public void addCheck(final SecretConsistencyCheck check) {
        checks.add(check);
    }

    public List<SecretConsistencyCheck> getChecks() {
        return checks;
    }

    public SecretService getSecretService() {
        return secretService;
    }

    public void setSecretService(final SecretService secretService) {
        this.secretService = secretService;
    }
}

==> open-xchange-core_7.0.2.orig.tar.bz2: open-xchange-core-7.0.2/com.openexchange.secret.recovery/src/com/openexchange/secret/recovery/impl/DefaultSecretInconsistencyDetector.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.secret.recovery.impl;

import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;
import org.apache.commons.logging.Log;
import com.openexchange.exception.OXException;
import com.openexchange.log.LogFactory;
import com.openexchange.secret.SecretService;
import com.openexchange.secret.recovery.SecretConsistencyCheck;
import com.openexchange.secret.recovery.SecretInconsistencyDetector;
import com.openexchange.tools.session.ServerSession;

/**
 * {@link DefaultSecretInconsistencyDetector}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class DefaultSecretInconsistencyDetector implements SecretInconsistencyDetector {

    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(DefaultSecretInconsistencyDetector.class));

    private static final boolean DEBUG = LOG.isDebugEnabled();

    private final List<SecretConsistencyCheck> checks;
    private volatile SecretService secretService;

    /**
     * Initializes a new {@link DefaultSecretInconsistencyDetector}.
     */
    public DefaultSecretInconsistencyDetector() {
        super();
        checks = new CopyOnWriteArrayList<SecretConsistencyCheck>();
    }

    @Override
    public String isSecretWorking(final ServerSession session) throws OXException {
        for (final SecretConsistencyCheck secretConsistencyCheck : getChecks()) {
            final String reason = secretConsistencyCheck.checkSecretCanDecryptStrings(session, getSecretService().getSecret(session));
            if (reason != null) {
                if (DEBUG) {
                    LOG.debug(SecretConsistencyCheck.class.getSimpleName() + " \"" + secretConsistencyCheck.getClass().getName() + "\" indicates need for re-decryption: " + reason);
                }
                return reason;
            }
        }
        return null;
    }

    /**
     * Adds given {@link SecretConsistencyCheck} instance.
     *
     * @param check The instance to add
     */
    public void addCheck(final SecretConsistencyCheck check) {
        checks.add(check);
    }

    /**
     * Gets available {@link SecretConsistencyCheck} instances.
     *
     * @return The instances
     */
    public List<SecretConsistencyCheck> getChecks() {
        return checks;
    }

    /**
     * Gets the associated {@link SecretService} instance.
     *
     * @return The instance
     */
    public SecretService getSecretService() {
        return secretService;
    }

    /**
     * Sets the associated {@link SecretService} instance.
     *
     * @param secretService The instance to set
     */
    public void setSecretService(final SecretService secretService) {
        this.secretService = secretService;
    }
}
